@@ -37,6 +37,7 @@ from plaid.model.address import Address
 from plaid.model.address_data import AddressData
 from plaid.model.address_data_nullable import AddressDataNullable
 from plaid.model.address_nullable import AddressNullable
+from plaid.model.address_purpose_label import AddressPurposeLabel
 from plaid.model.application import Application
 from plaid.model.application_get_request import ApplicationGetRequest
 from plaid.model.application_get_response import ApplicationGetResponse
@@ -124,9 +125,13 @@ from plaid.model.cause import Cause
 from plaid.model.cause_all_of import CauseAllOf
 from plaid.model.client_provided_enhanced_transaction import ClientProvidedEnhancedTransaction
 from plaid.model.client_provided_raw_transaction import ClientProvidedRawTransaction
+from plaid.model.client_user_id import ClientUserID
 from plaid.model.connected_application import ConnectedApplication
 from plaid.model.consent_payment_idempotency_key import ConsentPaymentIdempotencyKey
 from plaid.model.country_code import CountryCode
+from plaid.model.create_entity_screening_request import CreateEntityScreeningRequest
+from plaid.model.create_entity_watchlist_screening_review_request import CreateEntityWatchlistScreeningReviewRequest
+from plaid.model.create_individual_watchlist_screening_review_request import CreateIndividualWatchlistScreeningReviewRequest
 from plaid.model.credit_account_subtype import CreditAccountSubtype
 from plaid.model.credit_account_subtypes import CreditAccountSubtypes
 from plaid.model.credit_bank_income import CreditBankIncome
@@ -141,6 +146,9 @@ from plaid.model.credit_bank_income_get_response import CreditBankIncomeGetRespo
 from plaid.model.credit_bank_income_historical_summary import CreditBankIncomeHistoricalSummary
 from plaid.model.credit_bank_income_item import CreditBankIncomeItem
 from plaid.model.credit_bank_income_pay_frequency import CreditBankIncomePayFrequency
+from plaid.model.credit_bank_income_refresh_request import CreditBankIncomeRefreshRequest
+from plaid.model.credit_bank_income_refresh_request_options import CreditBankIncomeRefreshRequestOptions
+from plaid.model.credit_bank_income_refresh_response import CreditBankIncomeRefreshResponse
 from plaid.model.credit_bank_income_source import CreditBankIncomeSource
 from plaid.model.credit_bank_income_summary import CreditBankIncomeSummary
 from plaid.model.credit_bank_income_transaction import CreditBankIncomeTransaction
@@ -152,6 +160,7 @@ from plaid.model.credit_document_metadata import CreditDocumentMetadata
 from plaid.model.credit_employer_verification import CreditEmployerVerification
 from plaid.model.credit_employment_get_request import CreditEmploymentGetRequest
 from plaid.model.credit_employment_get_response import CreditEmploymentGetResponse
+from plaid.model.credit_employment_item import CreditEmploymentItem
 from plaid.model.credit_employment_verification import CreditEmploymentVerification
 from plaid.model.credit_filter import CreditFilter
 from plaid.model.credit_pay_stub import CreditPayStub
@@ -166,10 +175,18 @@ from plaid.model.credit_payroll_income_get_request import CreditPayrollIncomeGet
 from plaid.model.credit_payroll_income_get_response import CreditPayrollIncomeGetResponse
 from plaid.model.credit_payroll_income_precheck_request import CreditPayrollIncomePrecheckRequest
 from plaid.model.credit_payroll_income_precheck_response import CreditPayrollIncomePrecheckResponse
+from plaid.model.credit_payroll_income_refresh_request import CreditPayrollIncomeRefreshRequest
+from plaid.model.credit_payroll_income_refresh_response import CreditPayrollIncomeRefreshResponse
+from plaid.model.credit_payroll_income_risk_signals_get_request import CreditPayrollIncomeRiskSignalsGetRequest
+from plaid.model.credit_payroll_income_risk_signals_get_response import CreditPayrollIncomeRiskSignalsGetResponse
 from plaid.model.credit_platform_ids import CreditPlatformIds
 from plaid.model.credit_w2 import CreditW2
 from plaid.model.customer_initiated_return_risk import CustomerInitiatedReturnRisk
 from plaid.model.customer_initiated_risk_tier import CustomerInitiatedRiskTier
+from plaid.model.dashboard_user import DashboardUser
+from plaid.model.dashboard_user_list import DashboardUserList
+from plaid.model.dashboard_user_status import DashboardUserStatus
+from plaid.model.date_range import DateRange
 from plaid.model.deductions import Deductions
 from plaid.model.deductions_breakdown import DeductionsBreakdown
 from plaid.model.deductions_total import DeductionsTotal
@@ -192,7 +209,17 @@ from plaid.model.depository_account_subtypes import DepositoryAccountSubtypes
 from plaid.model.depository_filter import DepositoryFilter
 from plaid.model.distribution_breakdown import DistributionBreakdown
 from plaid.model.doc_type import DocType
+from plaid.model.document_analysis import DocumentAnalysis
+from plaid.model.document_authenticity_match_code import DocumentAuthenticityMatchCode
+from plaid.model.document_date_of_birth_match_code import DocumentDateOfBirthMatchCode
 from plaid.model.document_metadata import DocumentMetadata
+from plaid.model.document_name_match_code import DocumentNameMatchCode
+from plaid.model.document_risk_signal import DocumentRiskSignal
+from plaid.model.document_risk_signal_institution_metadata import DocumentRiskSignalInstitutionMetadata
+from plaid.model.document_risk_signals_object import DocumentRiskSignalsObject
+from plaid.model.document_status import DocumentStatus
+from plaid.model.documentary_verification import DocumentaryVerification
+from plaid.model.documentary_verification_document import DocumentaryVerificationDocument
 from plaid.model.earnings import Earnings
 from plaid.model.earnings_breakdown import EarningsBreakdown
 from plaid.model.earnings_breakdown_canonical_description import EarningsBreakdownCanonicalDescription
@@ -211,24 +238,77 @@ from plaid.model.employment_verification_get_request import EmploymentVerificati
 from plaid.model.employment_verification_get_response import EmploymentVerificationGetResponse
 from plaid.model.employment_verification_status import EmploymentVerificationStatus
 from plaid.model.enhancements import Enhancements
+from plaid.model.entity_document import EntityDocument
+from plaid.model.entity_document_type import EntityDocumentType
+from plaid.model.entity_screening_hit_analysis import EntityScreeningHitAnalysis
+from plaid.model.entity_screening_hit_data import EntityScreeningHitData
+from plaid.model.entity_screening_hit_documents_items import EntityScreeningHitDocumentsItems
+from plaid.model.entity_screening_hit_emails import EntityScreeningHitEmails
+from plaid.model.entity_screening_hit_emails_items import EntityScreeningHitEmailsItems
+from plaid.model.entity_screening_hit_names import EntityScreeningHitNames
+from plaid.model.entity_screening_hit_names_items import EntityScreeningHitNamesItems
+from plaid.model.entity_screening_hit_phone_numbers import EntityScreeningHitPhoneNumbers
+from plaid.model.entity_screening_hit_urls import EntityScreeningHitUrls
+from plaid.model.entity_screening_hit_urls_items import EntityScreeningHitUrlsItems
+from plaid.model.entity_screening_hits_phone_number_items import EntityScreeningHitsPhoneNumberItems
+from plaid.model.entity_screening_status_updated_webhook import EntityScreeningStatusUpdatedWebhook
+from plaid.model.entity_watchlist_code import EntityWatchlistCode
+from plaid.model.entity_watchlist_program import EntityWatchlistProgram
+from plaid.model.entity_watchlist_screening import EntityWatchlistScreening
+from plaid.model.entity_watchlist_screening_hit import EntityWatchlistScreeningHit
+from plaid.model.entity_watchlist_screening_hit_list import EntityWatchlistScreeningHitList
+from plaid.model.entity_watchlist_screening_list import EntityWatchlistScreeningList
+from plaid.model.entity_watchlist_screening_name import EntityWatchlistScreeningName
+from plaid.model.entity_watchlist_screening_program_list import EntityWatchlistScreeningProgramList
+from plaid.model.entity_watchlist_screening_program_name import EntityWatchlistScreeningProgramName
+from plaid.model.entity_watchlist_screening_review import EntityWatchlistScreeningReview
+from plaid.model.entity_watchlist_screening_search_terms import EntityWatchlistScreeningSearchTerms
+from plaid.model.entity_watchlist_search_terms import EntityWatchlistSearchTerms
 from plaid.model.error import Error
+from plaid.model.expiration_date import ExpirationDate
 from plaid.model.external_payment_initiation_consent_options import ExternalPaymentInitiationConsentOptions
 from plaid.model.external_payment_options import ExternalPaymentOptions
 from plaid.model.external_payment_refund_details import ExternalPaymentRefundDetails
 from plaid.model.external_payment_schedule_base import ExternalPaymentScheduleBase
 from plaid.model.external_payment_schedule_get import ExternalPaymentScheduleGet
 from plaid.model.external_payment_schedule_request import ExternalPaymentScheduleRequest
+from plaid.model.generic_country_code import GenericCountryCode
+from plaid.model.generic_screening_hit_location_items import GenericScreeningHitLocationItems
+from plaid.model.get_dashboard_user_request import GetDashboardUserRequest
+from plaid.model.get_entity_watchlist_screening_request import GetEntityWatchlistScreeningRequest
+from plaid.model.get_identity_verification_request import GetIdentityVerificationRequest
+from plaid.model.get_individual_watchlist_screening_request import GetIndividualWatchlistScreeningRequest
+from plaid.model.get_watchlist_screening_entity_program_request import GetWatchlistScreeningEntityProgramRequest
+from plaid.model.get_watchlist_screening_individual_program_request import GetWatchlistScreeningIndividualProgramRequest
 from plaid.model.health_incident import HealthIncident
 from plaid.model.historical_balance import HistoricalBalance
 from plaid.model.historical_update_webhook import HistoricalUpdateWebhook
 from plaid.model.holding import Holding
 from plaid.model.holdings_default_update_webhook import HoldingsDefaultUpdateWebhook
 from plaid.model.holdings_override import HoldingsOverride
+from plaid.model.id_number_type import IDNumberType
 from plaid.model.identity_default_update_webhook import IdentityDefaultUpdateWebhook
 from plaid.model.identity_get_request import IdentityGetRequest
 from plaid.model.identity_get_request_options import IdentityGetRequestOptions
 from plaid.model.identity_get_response import IdentityGetResponse
 from plaid.model.identity_update_types import IdentityUpdateTypes
+from plaid.model.identity_verification import IdentityVerification
+from plaid.model.identity_verification_create_request import IdentityVerificationCreateRequest
+from plaid.model.identity_verification_list import IdentityVerificationList
+from plaid.model.identity_verification_request_user import IdentityVerificationRequestUser
+from plaid.model.identity_verification_retried_webhook import IdentityVerificationRetriedWebhook
+from plaid.model.identity_verification_retry_request import IdentityVerificationRetryRequest
+from plaid.model.identity_verification_retry_request_steps_object import IdentityVerificationRetryRequestStepsObject
+from plaid.model.identity_verification_status import IdentityVerificationStatus
+from plaid.model.identity_verification_status_updated_webhook import IdentityVerificationStatusUpdatedWebhook
+from plaid.model.identity_verification_step_status import IdentityVerificationStepStatus
+from plaid.model.identity_verification_step_summary import IdentityVerificationStepSummary
+from plaid.model.identity_verification_step_updated_webhook import IdentityVerificationStepUpdatedWebhook
+from plaid.model.identity_verification_template_reference import IdentityVerificationTemplateReference
+from plaid.model.identity_verification_user_address import IdentityVerificationUserAddress
+from plaid.model.identity_verification_user_data import IdentityVerificationUserData
+from plaid.model.identity_verification_user_phone_number import IdentityVerificationUserPhoneNumber
+from plaid.model.image_quality import ImageQuality
 from plaid.model.incident_update import IncidentUpdate
 from plaid.model.income_breakdown import IncomeBreakdown
 from plaid.model.income_breakdown_type import IncomeBreakdownType
@@ -258,6 +338,11 @@ from plaid.model.income_verification_status_webhook import IncomeVerificationSta
 from plaid.model.income_verification_taxforms_get_request import IncomeVerificationTaxformsGetRequest
 from plaid.model.income_verification_taxforms_get_response import IncomeVerificationTaxformsGetResponse
 from plaid.model.income_verification_webhook_status import IncomeVerificationWebhookStatus
+from plaid.model.individual_screening_hit_names import IndividualScreeningHitNames
+from plaid.model.individual_watchlist_code import IndividualWatchlistCode
+from plaid.model.individual_watchlist_program import IndividualWatchlistProgram
+from plaid.model.individual_watchlist_program_list import IndividualWatchlistProgramList
+from plaid.model.individual_watchlist_screening_program_name import IndividualWatchlistScreeningProgramName
 from plaid.model.inflow_model import InflowModel
 from plaid.model.initial_update_webhook import InitialUpdateWebhook
 from plaid.model.institution import Institution
@@ -287,6 +372,7 @@ from plaid.model.investments_transactions_get_request import InvestmentsTransact
 from plaid.model.investments_transactions_get_request_options import InvestmentsTransactionsGetRequestOptions
 from plaid.model.investments_transactions_get_response import InvestmentsTransactionsGetResponse
 from plaid.model.investments_transactions_override import InvestmentsTransactionsOverride
+from plaid.model.issuing_country import IssuingCountry
 from plaid.model.item import Item
 from plaid.model.item_access_token_invalidate_request import ItemAccessTokenInvalidateRequest
 from plaid.model.item_access_token_invalidate_response import ItemAccessTokenInvalidateResponse
@@ -318,6 +404,12 @@ from plaid.model.item_webhook_update_request import ItemWebhookUpdateRequest
 from plaid.model.item_webhook_update_response import ItemWebhookUpdateResponse
 from plaid.model.jwk_public_key import JWKPublicKey
 from plaid.model.jwt_header import JWTHeader
+from plaid.model.kyc_check_address_summary import KYCCheckAddressSummary
+from plaid.model.kyc_check_date_of_birth_summary import KYCCheckDateOfBirthSummary
+from plaid.model.kyc_check_details import KYCCheckDetails
+from plaid.model.kyc_check_id_number_summary import KYCCheckIDNumberSummary
+from plaid.model.kyc_check_name_summary import KYCCheckNameSummary
+from plaid.model.kyc_check_phone_summary import KYCCheckPhoneSummary
 from plaid.model.liabilities_account_ids_with_updated_liabilities import LiabilitiesAccountIdsWithUpdatedLiabilities
 from plaid.model.liabilities_default_update_webhook import LiabilitiesDefaultUpdateWebhook
 from plaid.model.liabilities_get_request import LiabilitiesGetRequest
@@ -347,15 +439,31 @@ from plaid.model.link_token_eu_config import LinkTokenEUConfig
 from plaid.model.link_token_get_metadata_response import LinkTokenGetMetadataResponse
 from plaid.model.link_token_get_request import LinkTokenGetRequest
 from plaid.model.link_token_get_response import LinkTokenGetResponse
+from plaid.model.list_dashboard_user_request import ListDashboardUserRequest
+from plaid.model.list_entity_watchlist_screening_request import ListEntityWatchlistScreeningRequest
+from plaid.model.list_identity_verification_request import ListIdentityVerificationRequest
+from plaid.model.list_individual_watchlist_screening_request import ListIndividualWatchlistScreeningRequest
+from plaid.model.list_pagination import ListPagination
+from plaid.model.list_watchlist_screening_entity_history_request import ListWatchlistScreeningEntityHistoryRequest
+from plaid.model.list_watchlist_screening_entity_hit_request import ListWatchlistScreeningEntityHitRequest
+from plaid.model.list_watchlist_screening_entity_programs_request import ListWatchlistScreeningEntityProgramsRequest
+from plaid.model.list_watchlist_screening_entity_reviews_request import ListWatchlistScreeningEntityReviewsRequest
+from plaid.model.list_watchlist_screening_individual_history_request import ListWatchlistScreeningIndividualHistoryRequest
+from plaid.model.list_watchlist_screening_individual_hit_request import ListWatchlistScreeningIndividualHitRequest
+from plaid.model.list_watchlist_screening_individual_programs_request import ListWatchlistScreeningIndividualProgramsRequest
+from plaid.model.list_watchlist_screening_individual_reviews_request import ListWatchlistScreeningIndividualReviewsRequest
 from plaid.model.loan_account_subtype import LoanAccountSubtype
 from plaid.model.loan_account_subtypes import LoanAccountSubtypes
 from plaid.model.loan_filter import LoanFilter
 from plaid.model.location import Location
 from plaid.model.mfa import MFA
+from plaid.model.match_summary import MatchSummary
+from plaid.model.match_summary_code import MatchSummaryCode
 from plaid.model.meta import Meta
 from plaid.model.mortgage_interest_rate import MortgageInterestRate
 from plaid.model.mortgage_liability import MortgageLiability
 from plaid.model.mortgage_property_address import MortgagePropertyAddress
+from plaid.model.multi_document_risk_signal import MultiDocumentRiskSignal
 from plaid.model.net_pay import NetPay
 from plaid.model.new_accounts_available_webhook import NewAccountsAvailableWebhook
 from plaid.model.numbers import Numbers
@@ -371,7 +479,18 @@ from plaid.model.override_account_type import OverrideAccountType
 from plaid.model.override_accounts import OverrideAccounts
 from plaid.model.owner import Owner
 from plaid.model.owner_override import OwnerOverride
+from plaid.model.po_box_status import POBoxStatus
 from plaid.model.pslf_status import PSLFStatus
+from plaid.model.paginated_dashboard_user_list import PaginatedDashboardUserList
+from plaid.model.paginated_entity_watchlist_program_list import PaginatedEntityWatchlistProgramList
+from plaid.model.paginated_entity_watchlist_screening_hit_list import PaginatedEntityWatchlistScreeningHitList
+from plaid.model.paginated_entity_watchlist_screening_list import PaginatedEntityWatchlistScreeningList
+from plaid.model.paginated_entity_watchlist_screening_review_list import PaginatedEntityWatchlistScreeningReviewList
+from plaid.model.paginated_identity_verification_paginated_list import PaginatedIdentityVerificationPaginatedList
+from plaid.model.paginated_individual_watchlist_program_list import PaginatedIndividualWatchlistProgramList
+from plaid.model.paginated_individual_watchlist_screening_hit_list import PaginatedIndividualWatchlistScreeningHitList
+from plaid.model.paginated_individual_watchlist_screening_list import PaginatedIndividualWatchlistScreeningList
+from plaid.model.paginated_individual_watchlist_screening_review_list import PaginatedIndividualWatchlistScreeningReviewList
 from plaid.model.pay import Pay
 from plaid.model.pay_frequency import PayFrequency
 from plaid.model.pay_frequency_value import PayFrequencyValue
@@ -430,7 +549,6 @@ from plaid.model.payment_initiation_recipient_get_response import PaymentInitiat
 from plaid.model.payment_initiation_recipient_get_response_all_of import PaymentInitiationRecipientGetResponseAllOf
 from plaid.model.payment_initiation_recipient_list_request import PaymentInitiationRecipientListRequest
 from plaid.model.payment_initiation_recipient_list_response import PaymentInitiationRecipientListResponse
-from plaid.model.payment_initiation_refund import PaymentInitiationRefund
 from plaid.model.payment_initiation_refund_status import PaymentInitiationRefundStatus
 from plaid.model.payment_initiation_standing_order_metadata import PaymentInitiationStandingOrderMetadata
 from plaid.model.payment_meta import PaymentMeta
@@ -440,6 +558,7 @@ from plaid.model.payment_status_update_webhook import PaymentStatusUpdateWebhook
 from plaid.model.payroll_income_object import PayrollIncomeObject
 from plaid.model.payroll_item import PayrollItem
 from plaid.model.payroll_item_status import PayrollItemStatus
+from plaid.model.payroll_risk_signals_item import PayrollRiskSignalsItem
 from plaid.model.paystub import Paystub
 from plaid.model.paystub_address import PaystubAddress
 from plaid.model.paystub_deduction import PaystubDeduction
@@ -456,6 +575,12 @@ from plaid.model.paystub_ytd_details import PaystubYTDDetails
 from plaid.model.pending_expiration_webhook import PendingExpirationWebhook
 from plaid.model.personal_finance_category import PersonalFinanceCategory
 from plaid.model.phone_number import PhoneNumber
+from plaid.model.phone_type import PhoneType
+from plaid.model.physical_document_category import PhysicalDocumentCategory
+from plaid.model.physical_document_extracted_data import PhysicalDocumentExtractedData
+from plaid.model.physical_document_extracted_data_analysis import PhysicalDocumentExtractedDataAnalysis
+from plaid.model.physical_document_id_number import PhysicalDocumentIDNumber
+from plaid.model.physical_document_images import PhysicalDocumentImages
 from plaid.model.plaid_error import PlaidError
 from plaid.model.platform_ids import PlatformIds
 from plaid.model.processor_apex_processor_token_create_request import ProcessorApexProcessorTokenCreateRequest
@@ -477,6 +602,7 @@ from plaid.model.product_access import ProductAccess
 from plaid.model.product_status import ProductStatus
 from plaid.model.product_status_breakdown import ProductStatusBreakdown
 from plaid.model.products import Products
+from plaid.model.program_name_sensitivity import ProgramNameSensitivity
 from plaid.model.projected_income_summary_field_number import ProjectedIncomeSummaryFieldNumber
 from plaid.model.recaptcha_required_error import RecaptchaRequiredError
 from plaid.model.recipient_bacs import RecipientBACS
@@ -484,6 +610,8 @@ from plaid.model.recipient_bacs_nullable import RecipientBACSNullable
 from plaid.model.recurring_transaction_frequency import RecurringTransactionFrequency
 from plaid.model.relay_event import RelayEvent
 from plaid.model.removed_transaction import RemovedTransaction
+from plaid.model.review_comment import ReviewComment
+from plaid.model.risk_signal_document_reference import RiskSignalDocumentReference
 from plaid.model.sandbox_bank_transfer_fire_webhook_request import SandboxBankTransferFireWebhookRequest
 from plaid.model.sandbox_bank_transfer_fire_webhook_response import SandboxBankTransferFireWebhookResponse
 from plaid.model.sandbox_bank_transfer_simulate_request import SandboxBankTransferSimulateRequest
@@ -516,6 +644,12 @@ from plaid.model.sandbox_transfer_sweep_simulate_response import SandboxTransfer
 from plaid.model.scopes import Scopes
 from plaid.model.scopes_context import ScopesContext
 from plaid.model.scopes_nullable import ScopesNullable
+from plaid.model.screening_hit_analysis import ScreeningHitAnalysis
+from plaid.model.screening_hit_data import ScreeningHitData
+from plaid.model.screening_hit_date_of_birth_item import ScreeningHitDateOfBirthItem
+from plaid.model.screening_hit_documents_items import ScreeningHitDocumentsItems
+from plaid.model.screening_hit_names_items import ScreeningHitNamesItems
+from plaid.model.screening_status_updated_webhook import ScreeningStatusUpdatedWebhook
 from plaid.model.security import Security
 from plaid.model.security_override import SecurityOverride
 from plaid.model.sender_bacs_nullable import SenderBACSNullable
@@ -528,19 +662,26 @@ from plaid.model.signal_evaluate_core_attributes import SignalEvaluateCoreAttrib
 from plaid.model.signal_evaluate_request import SignalEvaluateRequest
 from plaid.model.signal_evaluate_response import SignalEvaluateResponse
 from plaid.model.signal_person_name import SignalPersonName
+from plaid.model.signal_prepare_request import SignalPrepareRequest
+from plaid.model.signal_prepare_response import SignalPrepareResponse
 from plaid.model.signal_return_report_request import SignalReturnReportRequest
 from plaid.model.signal_return_report_response import SignalReturnReportResponse
 from plaid.model.signal_score import SignalScore
 from plaid.model.signal_scores import SignalScores
 from plaid.model.signal_user import SignalUser
 from plaid.model.simulated_transfer_sweep import SimulatedTransferSweep
+from plaid.model.single_document_risk_signal import SingleDocumentRiskSignal
+from plaid.model.source import Source
+from plaid.model.source_uid import SourceUID
 from plaid.model.standalone_account_type import StandaloneAccountType
 from plaid.model.standalone_currency_code_list import StandaloneCurrencyCodeList
 from plaid.model.standalone_investment_transaction_type import StandaloneInvestmentTransactionType
+from plaid.model.strategy import Strategy
 from plaid.model.student_loan import StudentLoan
 from plaid.model.student_loan_repayment_model import StudentLoanRepaymentModel
 from plaid.model.student_loan_status import StudentLoanStatus
 from plaid.model.student_repayment_plan import StudentRepaymentPlan
+from plaid.model.sync_updates_available_webhook import SyncUpdatesAvailableWebhook
 from plaid.model.taxform import Taxform
 from plaid.model.taxpayer_id import TaxpayerID
 from plaid.model.total import Total
@@ -576,6 +717,7 @@ from plaid.model.transactions_rules_list_response import TransactionsRulesListRe
 from plaid.model.transactions_rules_remove_request import TransactionsRulesRemoveRequest
 from plaid.model.transactions_rules_remove_response import TransactionsRulesRemoveResponse
 from plaid.model.transactions_sync_request import TransactionsSyncRequest
+from plaid.model.transactions_sync_request_options import TransactionsSyncRequestOptions
 from plaid.model.transactions_sync_response import TransactionsSyncResponse
 from plaid.model.transfer import Transfer
 from plaid.model.transfer_authorization import TransferAuthorization
@@ -639,9 +781,16 @@ from plaid.model.transfer_user_address_in_request import TransferUserAddressInRe
 from plaid.model.transfer_user_address_in_response import TransferUserAddressInResponse
 from plaid.model.transfer_user_in_request import TransferUserInRequest
 from plaid.model.transfer_user_in_response import TransferUserInResponse
+from plaid.model.update_entity_screening_request import UpdateEntityScreeningRequest
+from plaid.model.update_entity_screening_request_search_terms import UpdateEntityScreeningRequestSearchTerms
+from plaid.model.update_individual_screening_request import UpdateIndividualScreeningRequest
+from plaid.model.update_individual_screening_request_search_terms import UpdateIndividualScreeningRequestSearchTerms
+from plaid.model.user_address import UserAddress
 from plaid.model.user_create_request import UserCreateRequest
 from plaid.model.user_create_response import UserCreateResponse
 from plaid.model.user_custom_password import UserCustomPassword
+from plaid.model.user_id_number import UserIDNumber
+from plaid.model.user_name import UserName
 from plaid.model.user_permission_revoked_webhook import UserPermissionRevokedWebhook
 from plaid.model.verification_attribute import VerificationAttribute
 from plaid.model.verification_expired_webhook import VerificationExpiredWebhook
@@ -650,9 +799,13 @@ from plaid.model.verification_status import VerificationStatus
 from plaid.model.w2 import W2
 from plaid.model.w2_box12 import W2Box12
 from plaid.model.w2_state_and_local_wages import W2StateAndLocalWages
+from plaid.model.wallet import Wallet
 from plaid.model.wallet_balance import WalletBalance
+from plaid.model.wallet_create_request import WalletCreateRequest
+from plaid.model.wallet_create_response import WalletCreateResponse
 from plaid.model.wallet_get_request import WalletGetRequest
 from plaid.model.wallet_get_response import WalletGetResponse
+from plaid.model.wallet_iso_currency_code import WalletISOCurrencyCode
 from plaid.model.wallet_numbers import WalletNumbers
 from plaid.model.wallet_transaction import WalletTransaction
 from plaid.model.wallet_transaction_amount import WalletTransactionAmount
@@ -661,11 +814,33 @@ from plaid.model.wallet_transaction_counterparty_bacs import WalletTransactionCo
 from plaid.model.wallet_transaction_counterparty_numbers import WalletTransactionCounterpartyNumbers
 from plaid.model.wallet_transaction_execute_request import WalletTransactionExecuteRequest
 from plaid.model.wallet_transaction_execute_response import WalletTransactionExecuteResponse
+from plaid.model.wallet_transaction_get_request import WalletTransactionGetRequest
+from plaid.model.wallet_transaction_get_response import WalletTransactionGetResponse
 from plaid.model.wallet_transaction_idempotency_key import WalletTransactionIdempotencyKey
 from plaid.model.wallet_transaction_status import WalletTransactionStatus
 from plaid.model.wallet_transactions_list_request import WalletTransactionsListRequest
 from plaid.model.wallet_transactions_list_response import WalletTransactionsListResponse
 from plaid.model.warning import Warning
+from plaid.model.watchlist_screening_audit_trail import WatchlistScreeningAuditTrail
+from plaid.model.watchlist_screening_create_request import WatchlistScreeningCreateRequest
+from plaid.model.watchlist_screening_document import WatchlistScreeningDocument
+from plaid.model.watchlist_screening_document_type import WatchlistScreeningDocumentType
+from plaid.model.watchlist_screening_document_value import WatchlistScreeningDocumentValue
+from plaid.model.watchlist_screening_entity_review_list import WatchlistScreeningEntityReviewList
+from plaid.model.watchlist_screening_hit import WatchlistScreeningHit
+from plaid.model.watchlist_screening_hit_list import WatchlistScreeningHitList
+from plaid.model.watchlist_screening_hit_locations import WatchlistScreeningHitLocations
+from plaid.model.watchlist_screening_hit_status import WatchlistScreeningHitStatus
+from plaid.model.watchlist_screening_individual import WatchlistScreeningIndividual
+from plaid.model.watchlist_screening_individual_name import WatchlistScreeningIndividualName
+from plaid.model.watchlist_screening_list import WatchlistScreeningList
+from plaid.model.watchlist_screening_phone_number import WatchlistScreeningPhoneNumber
+from plaid.model.watchlist_screening_request_search_terms import WatchlistScreeningRequestSearchTerms
+from plaid.model.watchlist_screening_review import WatchlistScreeningReview
+from plaid.model.watchlist_screening_review_list import WatchlistScreeningReviewList
+from plaid.model.watchlist_screening_search_terms import WatchlistScreeningSearchTerms
+from plaid.model.watchlist_screening_status import WatchlistScreeningStatus
+from plaid.model.weak_alias_determination import WeakAliasDetermination
 from plaid.model.webhook_type import WebhookType
 from plaid.model.webhook_update_acknowledged_webhook import WebhookUpdateAcknowledgedWebhook
 from plaid.model.webhook_verification_key_get_request import WebhookVerificationKeyGetRequest
